/* SPDX-License-Identifier: GPL-2.0-only */
/*
 * Copyright (C) 2019 Martin Blumenstingl <martin.blumenstingl@googlemail.com>
 */

#define LANTIQ_PCIE_PHY_MODE_25MHZ		0
#define LANTIQ_PCIE_PHY_MODE_25MHZ_SSC		1
#define LANTIQ_PCIE_PHY_MODE_36MHZ		2
#define LANTIQ_PCIE_PHY_MODE_36MHZ_SSC		3
#define LANTIQ_PCIE_PHY_MODE_100MHZ		4
#define LANTIQ_PCIE_PHY_MODE_100MHZ_SSC		5
